/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ApiRootService } from '@alfa-client/api-root-shared';
import { Environment, ENVIRONMENT_CONFIG } from '@alfa-client/environment-shared';
import { NavigationSharedModule } from '@alfa-client/navigation-shared';
import { ResourceRepository, TechSharedModule } from '@alfa-client/tech-shared';
import { UiModule } from '@alfa-client/ui';
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { RouterModule } from '@angular/router';
import KcAdminClient from '@keycloak/keycloak-admin-client';
import {
  ButtonWithSpinnerComponent,
  CheckboxEditorComponent,
  TextareaEditorComponent,
  TextEditorComponent,
} from '@ods/component';
import {
  ExclamationIconComponent,
  ListComponent,
  ListItemComponent,
  MailboxIconComponent,
  PersonIconComponent,
  TextInputComponent,
} from '@ods/system';
import { createSettingListResourceService, SettingListResourceService } from './admin-settings-resource.service';
import { SettingsService } from './admin-settings.service';
import { ConfigurationResourceService, createConfigurationResourceService } from './configuration/configuration-resource.service';
import { ConfigurationService } from './configuration/configuration.service';
import {
  createOrganisationsEinheitListResourceService,
  OrganisationsEinheitListResourceService,
} from './organisationseinheit/organisations-einheit-list-resource.service';
import {
  createOrganisationsEinheitResourceService,
  OrganisationsEinheitResourceService,
} from './organisationseinheit/organisations-einheit-resource.service';
import { OrganisationsEinheitContainerComponent } from './organisationseinheit/organisationseinheit-container/organisationseinheit-container.component';
import { OrganisationsEinheitListComponent } from './organisationseinheit/organisationseinheit-container/organisationseinheit-list/organisationseinheit-list.component';
import { OrganisationsEinheitFormContainerComponent } from './organisationseinheit/organisationseinheit-form-container/organisationseinheit-form-container.component';
import { OrganisationsEinheitFormComponent } from './organisationseinheit/organisationseinheit-form-container/organisationseinheit-form/organisationseinheit-form.component';
import { OrganisationsEinheitSignaturComponent } from './organisationseinheit/organisationseinheit-form-container/organisationseinheit-form/organisationseinheit-signatur/organisationseinheit-signatur.component';
import { PostfachContainerComponent } from './postfach/postfach-container/postfach-container.component';
import { PostfachFormComponent } from './postfach/postfach-container/postfach-form/postfach-form.component';
import { PostfachSignaturComponent } from './postfach/postfach-container/postfach-form/postfach-signatur/postfach-signatur.component';
import { createPostfachResourceService, PostfachResourceService } from './postfach/postfach-resource.service';
import { PostfachService } from './postfach/postfach.service';
import { ToUserNamePipe } from './user/to-user-name.pipe';
import { UserAddFormComponent } from './users-roles/user-add-form/user-add-form.component';
import { UsersRolesComponent } from './users-roles/users-roles.component';

@NgModule({
  declarations: [
    PostfachContainerComponent,
    PostfachFormComponent,
    PostfachSignaturComponent,
    OrganisationsEinheitContainerComponent,
    OrganisationsEinheitListComponent,
    OrganisationsEinheitFormContainerComponent,
    OrganisationsEinheitFormComponent,
    OrganisationsEinheitSignaturComponent,
    UsersRolesComponent,
    UserAddFormComponent,
  ],
  imports: [
    CommonModule,
    TechSharedModule,
    RouterModule,
    ReactiveFormsModule,
    TextInputComponent,
    CheckboxEditorComponent,
    ButtonWithSpinnerComponent,
    TextareaEditorComponent,
    MailboxIconComponent,
    PersonIconComponent,
    ToUserNamePipe,
    ListComponent,
    ListItemComponent,
    ExclamationIconComponent,
    UiModule,
    NavigationSharedModule,
    TextEditorComponent,
  ],
  exports: [
    PostfachContainerComponent,
    OrganisationsEinheitContainerComponent,
    OrganisationsEinheitFormContainerComponent,
    UsersRolesComponent,
    UserAddFormComponent,
  ],
  providers: [
    ConfigurationService,
    SettingsService,
    PostfachService,
    {
      provide: KcAdminClient,
      useFactory: (env: Environment) =>
        new KcAdminClient({
          baseUrl: env.authServer,
          realmName: env.realm,
        }),
      deps: [ENVIRONMENT_CONFIG],
    },
    {
      provide: PostfachResourceService,
      useFactory: createPostfachResourceService,
      deps: [ResourceRepository, SettingsService],
    },
    {
      provide: ConfigurationResourceService,
      useFactory: createConfigurationResourceService,
      deps: [ResourceRepository, ApiRootService],
    },
    {
      provide: SettingListResourceService,
      useFactory: createSettingListResourceService,
      deps: [ResourceRepository, ConfigurationService],
    },
    {
      provide: OrganisationsEinheitListResourceService,
      useFactory: createOrganisationsEinheitListResourceService,
      deps: [ResourceRepository, ApiRootService],
    },
    {
      provide: OrganisationsEinheitResourceService,
      useFactory: createOrganisationsEinheitResourceService,
      deps: [ResourceRepository, OrganisationsEinheitListResourceService],
    },
  ],
})
export class AdminSettingsModule {}
