/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { AdminOrganisationsEinheitResource } from '@admin-client/admin-settings';
import { StateResource, createEmptyStateResource, isNotNil } from '@alfa-client/tech-shared';
import { Component, Input } from '@angular/core';
import { Resource } from '@ngxp/rest';
import { Observable, of } from 'rxjs';
import { OrganisationsEinheitFormService } from './organisationseinheit.formservice';

@Component({
  selector: 'admin-organisationseinheit-form',
  templateUrl: './organisationseinheit-form.component.html',
  providers: [OrganisationsEinheitFormService],
})
export class OrganisationsEinheitFormComponent {
  submitInProgress$: Observable<StateResource<Resource>> = of(createEmptyStateResource<Resource>());

  @Input() set organisationsEinheitStateResource(stateResource: StateResource<AdminOrganisationsEinheitResource>) {
    this.updateOrganisationsEinheitResource(stateResource.resource);
  }

  updateOrganisationsEinheitResource(organisationsEinheitResource: AdminOrganisationsEinheitResource): void {
    if (isNotNil(organisationsEinheitResource)) {
      this.formService.patch(organisationsEinheitResource.settings);
    }
  }

  constructor(public formService: OrganisationsEinheitFormService) {}

  public submit(): void {
    this.submitInProgress$ = this.formService.submit();
  }
}
