/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getElementFromFixture, mock, Mock } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule } from '@angular/forms';
import { TextareaEditorComponent } from '@ods/component';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { PostfachService } from '../../../postfach.service';
import { PostfachFormComponent } from '../postfach-form.component';
import { PostfachFormService } from '../postfach.formservice';
import { PostfachSignaturComponent } from './postfach-signatur.component';

describe('PostfachSignaturComponent', () => {
  let component: PostfachSignaturComponent;
  let fixture: ComponentFixture<PostfachSignaturComponent>;

  let formService: Mock<PostfachFormService>;
  let postfachService: Mock<PostfachService>;
  const signaturTextarea = getDataTestIdOf('signatur-text');

  beforeEach(async () => {
    formService = mock(PostfachFormService);
    postfachService = mock(PostfachService);
    await TestBed.configureTestingModule({
      imports: [ReactiveFormsModule],
      declarations: [PostfachFormComponent, MockComponent(TextareaEditorComponent)],
      providers: [
        {
          provide: PostfachFormService,
          useValue: formService,
        },
        {
          provide: PostfachService,
          useValue: postfachService,
        },
      ],
    }).compileComponents();
    fixture = TestBed.createComponent(PostfachSignaturComponent);
    TestBed.inject(PostfachService);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  describe('template', () => {
    it('should create', () => {
      expect(component).toBeTruthy();
    });

    describe('ods-textarea-editor', () => {
      describe('input', () => {
        it('should set formControlName to Signatur Field', () => {
          const textAreaEditor = getElementFromFixture(fixture, signaturTextarea);

          expect(textAreaEditor.getAttribute('rows')).toEqual('6');
        });
      });
    });
  });
});
