/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { getElementFromFixture } from '@alfa-client/test-utils';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ReactiveFormsModule } from '@angular/forms';
import { faker } from '@faker-js/faker';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { ValidationErrorComponent } from '../validation-error/validation-error.component';
import { TextEditorComponent } from './text-editor.component';

describe('TextEditorComponent', () => {
  let component: TextEditorComponent;
  let fixture: ComponentFixture<TextEditorComponent>;

  const labelText: string = faker.word.noun();
  const inputTestId: string = getDataTestIdOf(labelText + '-text-editor');
  const errorId: string = getDataTestIdOf(labelText + '-text-editor-error');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [TextEditorComponent, MockComponent(ValidationErrorComponent)],
      imports: [TextEditorComponent, ReactiveFormsModule],
    }).compileComponents();

    fixture = TestBed.createComponent(TextEditorComponent);
    component = fixture.componentInstance;
    component.label = labelText;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  it('should have text editor', () => {
    const element: HTMLElement = getElementFromFixture(fixture, inputTestId);

    expect(element).toBeInstanceOf(HTMLElement);
  });

  it('should have focus set to false by default', () => {
    expect(component.focus).toBeFalsy();
  });

  describe('errors', () => {
    it('should be hidden', () => {
      const element: HTMLElement = getElementFromFixture(fixture, errorId);

      expect(element).toBeEmptyDOMElement();
    });

    // TODO: Set error and test for 'should be visible
  });
});
