/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { type Meta, type StoryObj } from '@storybook/angular';
import { AttachmentComponent } from './attachment.component';

const meta: Meta<AttachmentComponent> = {
  title: 'Attachment',
  component: AttachmentComponent,
  excludeStories: /.*Data$/,
  tags: ['autodocs'],
};

export default meta;
type Story = StoryObj<AttachmentComponent>;

export const Default: Story = {
  name: 'File with pdf icon',
  args: {
    caption: 'Katzenanmeldung_1231231_eingang.pdf',
    errorCaption: 'Error!',
    loadingCaption: 'Loading...',
    description: '450 kB',
    fileType: 'pdf',
    isLoading: false,
    errorMessages: [],
  },
  argTypes: {
    caption: {
      description: 'Name of the document',
    },
    errorCaption: {
      description: 'Error text appears when eror messages array is not empty',
    },
    loadingCaption: {
      description: 'Loading text appears when isLoading flag is true',
    },
    description: {
      description: 'Description can contain size of file or e.g. loading progress',
    },
    fileType: {
      description: 'Type of file icon',
    },
    isLoading: {
      description: 'Boolean flag for loading state',
      table: {
        defaultValue: { summary: 'false' },
      },
    },
    errorMessages: {
      description: 'The array containing strings with errors text',
    },
  },
};

export const Doc: Story = {
  name: 'File with doc icon',
  args: {
    caption: 'Katzenanmeldung_1231231_eingang.doc',
    description: '573 kB',
    fileType: 'doc',
  },
};

export const Loading: Story = {
  name: 'File with loading icon',
  args: {
    loadingCaption: 'Katzenanmeldung_1231231_eingang.doc',
    description: '573 kB',
    fileType: 'doc',
    isLoading: true,
  },
};

export const Error: Story = {
  name: 'Error message in file',
  args: {
    errorCaption: 'Fehler beim Hochladen',
    errorMessages: ['Erlaubte Dateiendungen: pdf, jpg, png, jpeg'],
  },
};
