/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { CommandOrder, CommandResource } from '@alfa-client/command-shared';
import { KommentarResource } from '@alfa-client/kommentar-shared';
import { getElementFromFixture } from '@alfa-client/test-utils';
import { createCommandResource } from 'libs/command-shared/test/command';
import { getDataTestClassOf } from 'libs/tech-shared/test/data-test';
import { MockComponent } from 'ng-mocks';
import { createKommentarResource } from '../../../../../../kommentar-shared/test/kommentar';
import { ExpansionPanelWithUserComponent } from '../expansion-panel-with-user/expansion-panel-with-user.component';
import { HistorieItemAttachmentComponent } from '../historie-item-attachment/historie-item-attachment.component';
import { HistorieItemKommentarComponent } from './historie-item-kommentar.component';

describe('HistorieItemKommentarComponent', () => {
  let component: HistorieItemKommentarComponent;
  let fixture: ComponentFixture<HistorieItemKommentarComponent>;

  const kommentarCommand: CommandResource = {
    ...createCommandResource(),
    order: CommandOrder.CREATE_KOMMENTAR,
    body: { item: { text: 'Beispiel text fuer einen Kommentar' } },
  };

  const attachment: string = getDataTestClassOf('historie-item-kommentar-attachment');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        HistorieItemKommentarComponent,
        MockComponent(ExpansionPanelWithUserComponent),
        MockComponent(HistorieItemAttachmentComponent),
      ],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(HistorieItemKommentarComponent);
    component = fixture.componentInstance;
    component.command = kommentarCommand;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should set headline for order ' + CommandOrder.CREATE_KOMMENTAR, () => {
      component.command = { ...kommentarCommand, order: CommandOrder.CREATE_KOMMENTAR };

      component.ngOnInit();

      expect(component.headline).toBe(`ein Kommentar hinzugefügt.`);
    });

    it('should set headline for order' + CommandOrder.EDIT_KOMMENTAR, () => {
      component.command = { ...kommentarCommand, order: CommandOrder.EDIT_KOMMENTAR };

      component.ngOnInit();

      expect(component.headline).toBe(`ein Kommentar bearbeitet.`);
    });
  });

  describe('attachments', () => {
    beforeEach(() => {
      component.command = createCommand(createKommentarResource());
    });

    it('should hide of NOT exists', () => {
      const item: KommentarResource = createKommentarResource();
      delete item['attachments'];
      component.command = createCommand(item);
      fixture.detectChanges();

      const attachmentElement = getElementFromFixture(fixture, attachment);

      expect(attachmentElement).not.toBeInstanceOf(HTMLElement);
    });

    it('should show if exists', () => {
      component.command = createCommand(createKommentarResource());
      fixture.detectChanges();

      const attachmentElement = getElementFromFixture(fixture, attachment);

      expect(attachmentElement).toBeInstanceOf(HTMLElement);
    });

    function createCommand(item: KommentarResource): CommandResource {
      return { ...createCommandResource(), order: CommandOrder.CREATE_KOMMENTAR, body: { item } };
    }
  });
});
