/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { HasLinkPipe, StateResource, createStateResource } from '@alfa-client/tech-shared';
import { getElementFromFixture, mock } from '@alfa-client/test-utils';
import { OzgcloudButtonWithSpinnerComponent } from '@alfa-client/ui';
import { VorgangService, VorgangWithEingangLinkRel } from '@alfa-client/vorgang-shared';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { ExclamationIconComponent } from '@ods/system';
import { getDataTestIdOf } from 'libs/tech-shared/test/data-test';
import { createVorgangWithEingangResource } from 'libs/vorgang-shared/test/vorgang';
import { MockComponent } from 'ng-mocks';
import { of } from 'rxjs';
import { VorgangExportContainerComponent } from './vorgang-export-container.component';

describe('VorgangExportContainerComponent', () => {
  let component: VorgangExportContainerComponent;
  let fixture: ComponentFixture<VorgangExportContainerComponent>;

  const vorgangExportStateResource: StateResource<boolean> = createStateResource(false);
  const vorgangService = mock(VorgangService);

  const buttonWithSpinner: string = '[dataTestId="export-vorgang"]';
  const cannotExportMessageDataTestId: string = getDataTestIdOf('cannot-export-vorgang');

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        HasLinkPipe,
        VorgangExportContainerComponent,
        MockComponent(OzgcloudButtonWithSpinnerComponent),
        MockComponent(ExclamationIconComponent),
      ],
      providers: [
        {
          provide: VorgangService,
          useValue: vorgangService,
        },
      ],
    }).compileComponents();

    fixture = TestBed.createComponent(VorgangExportContainerComponent);
    component = fixture.componentInstance;
    vorgangService.getVorgangExport.mockReturnValue(of(vorgangExportStateResource));
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('ngOnInit', () => {
    it('should get export', () => {
      component.ngOnInit();

      expect(vorgangService.getVorgangExport).toHaveBeenCalled();
    });
  });

  describe('isExportDone', () => {
    it('should closeMenu if export is done', () => {
      jest.spyOn(component.closeMenu, 'emit');

      component.isExportDone(createStateResource(true));

      expect(component.closeMenu.emit).toHaveBeenCalled();
    });
  });

  describe('export', () => {
    it('should call vorgangService.export with vorgang', () => {
      component.export();

      expect(vorgangService.export).toHaveBeenCalledWith(component.vorgangWithEingang);
    });
  });

  describe('show export button or message', () => {
    it('should show button, if there is export link', () => {
      component.vorgangWithEingang = createVorgangWithEingangResource([VorgangWithEingangLinkRel.EXPORT]);
      fixture.detectChanges();

      const element = getElementFromFixture(fixture, buttonWithSpinner);

      expect(element).toBeInstanceOf(HTMLElement);
    });

    it('should show message, if there is no export link', () => {
      component.vorgangWithEingang = createVorgangWithEingangResource();
      fixture.detectChanges();

      const element = getElementFromFixture(fixture, cannotExportMessageDataTestId);

      expect(element).toBeInstanceOf(HTMLElement);
    });
  });
});
