/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import {
  ConvertForDataTestPipe,
  FormatToPrettyDatePipe,
  HasLinkPipe,
  ToResourceUriPipe,
  ToTrafficLightTooltipPipe,
  formatFullDate,
} from '@alfa-client/tech-shared';
import { dispatchEventFromFixture } from '@alfa-client/test-utils';
import { ExpansionPanelComponent } from '@alfa-client/ui';
import {
  LinkWithUserNameTooltipContainerComponent,
  TextWithUserNameTooltipContainerComponent,
} from '@alfa-client/user-profile';
import { WiedervorlageResource } from '@alfa-client/wiedervorlage-shared';
import { registerLocaleData } from '@angular/common';
import localeDe from '@angular/common/locales/de';
import localeDeExtra from '@angular/common/locales/extra/de';
import { LOCALE_ID } from '@angular/core';
import { ComponentFixture, TestBed } from '@angular/core/testing';
import { MAT_DATE_LOCALE } from '@angular/material/core';
import { MatIcon } from '@angular/material/icon';
import { MatTooltipModule } from '@angular/material/tooltip';
import { RouterTestingModule } from '@angular/router/testing';
import { createWiedervorlageResource } from 'libs/wiedervorlage-shared/test/wiedervorlage';
import { MockComponent, MockModule } from 'ng-mocks';
import { WiedervorlageStatusComponent } from '../../../wiedervorlage-status/wiedervorlage-status.component';
import { WiedervorlageAttachmentListContainerComponent } from './wiedervorlage-attachment-list-container/wiedervorlage-attachment-list-container.component';
import { WiedervorlageInVorgangExpandButtonComponent } from './wiedervorlage-in-vorgang-expand-button/wiedervorlage-in-vorgang-expand-button.component';
import { WiedervorlageInVorgangComponent } from './wiedervorlage-in-vorgang.component';

registerLocaleData(localeDe, 'de', localeDeExtra);

describe('WiedervorlageInVorgangComponent', () => {
  let component: WiedervorlageInVorgangComponent;
  let fixture: ComponentFixture<WiedervorlageInVorgangComponent>;

  const expandable: string = '[data-test-class="expandable"]';
  const expandButton: string = '[data-test-class="expand-button"]';
  const wiedervorlage: WiedervorlageResource = createWiedervorlageResource();

  beforeEach(async () => {
    await TestBed.configureTestingModule({
      declarations: [
        WiedervorlageInVorgangComponent,
        FormatToPrettyDatePipe,
        ToResourceUriPipe,
        ToTrafficLightTooltipPipe,
        ConvertForDataTestPipe,
        MatIcon,
        HasLinkPipe,
        MockComponent(ExpansionPanelComponent),
        MockComponent(WiedervorlageStatusComponent),
        MockComponent(WiedervorlageAttachmentListContainerComponent),
        MockComponent(WiedervorlageInVorgangExpandButtonComponent),
        MockComponent(LinkWithUserNameTooltipContainerComponent),
        MockComponent(TextWithUserNameTooltipContainerComponent),
        MockModule(MatTooltipModule),
      ],
      imports: [RouterTestingModule],
      providers: [
        { provide: LOCALE_ID, useValue: 'de' },
        { provide: MAT_DATE_LOCALE, useValue: 'de-DE' },
      ],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(WiedervorlageInVorgangComponent);
    component = fixture.componentInstance;
    component.wiedervorlageResource = wiedervorlage;
    fixture.detectChanges();
  });

  it('should create', () => {
    expect(component).toBeTruthy();
  });

  describe('tooltip', () => {
    it('should build Tooltip', () => {
      const expectedTooltip: string = `${wiedervorlage.betreff}, erstellt am ${formatFullDate(wiedervorlage.createdAt)} von`;

      const tooltip: string = component.formatTooltip();

      expect(tooltip).toContain(expectedTooltip);
    });
  });

  it('should have data test id', () => {
    component.wiedervorlageResource = {
      ...createWiedervorlageResource(),
      betreff: 'Hier steht ein Betreff',
    };
    fixture.detectChanges();

    const element = fixture.nativeElement.querySelector('[data-test-id="Hier_steht_ein_Betreff"]');

    expect(element).toBeInstanceOf(HTMLElement);
  });

  describe('beschreibung', () => {
    it('should be hidden initially', () => {
      const betreff = fixture.nativeElement.querySelector(expandable);

      expect(betreff).not.toBeInstanceOf(HTMLElement);
    });

    it('should be visible on click', () => {
      dispatchEventFromFixture(fixture, expandButton, 'toggle');
      fixture.detectChanges();

      const betreff = fixture.nativeElement.querySelector(expandable);

      expect(betreff).toBeInstanceOf(HTMLElement);
    });
  });
});
