/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
import { faker } from '@faker-js/faker';
import { toResource } from 'libs/tech-shared/test/resource';
import { times } from 'lodash-es';
import { ExterneFachstelleListLinkRel } from '../src/lib/externe-fachstelle/externe-fachstelle.linkrel';
import {
  ExterneFachstelle,
  ExterneFachstelleListResource,
  ExterneFachstelleResource,
} from '../src/lib/externe-fachstelle/externe-fachstelle.model';

export function createExterneFachstelle(): ExterneFachstelle {
  return {
    name: faker.lorem.word(),
    anschrift: faker.lorem.words(5),
    email: faker.internet.email(),
  };
}

export function createExterneFachstelleResource(linkRel: string[] = []): ExterneFachstelleResource {
  return toResource(createExterneFachstelle(), linkRel);
}

export function createExterneFachstelleResources(linkRelations: string[] = []): ExterneFachstelleResource[] {
  return times(10, () => toResource(createExterneFachstelleResource(), [...linkRelations]));
}

export function createExterneFachstelleListResource(
  resources?: ExterneFachstelleResource[],
  linkRelations: string[] = [],
): ExterneFachstelleListResource {
  return toResource({}, [...linkRelations], {
    [ExterneFachstelleListLinkRel.EXTERNE_FACHSTELLE_LIST]: resources ? resources : createExterneFachstelleResources(),
  });
}
