/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.postfach;

import java.time.ZonedDateTime;
import java.util.List;
import java.util.UUID;

import org.apache.commons.lang3.RandomStringUtils;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.alfa.common.binaryfile.BinaryFileTestFactory;
import de.ozgcloud.alfa.common.binaryfile.FileId;
import de.ozgcloud.alfa.common.command.CommandOrder;
import de.ozgcloud.alfa.common.user.UserId;
import de.ozgcloud.alfa.common.user.UserProfileTestFactory;
import de.ozgcloud.alfa.postfach.PostfachMail.Direction;
import de.ozgcloud.alfa.vorgang.VorgangHeaderTestFactory;
import de.ozgcloud.common.test.TestUtils;

public class PostfachMailTestFactory {

	public static final String ID = UUID.randomUUID().toString();
	public static final PostfachNachrichtId NACHRICHT_ID = PostfachNachrichtId.from(ID);
	public static final String VORGANG_ID = VorgangHeaderTestFactory.ID;
	public static final String CREATED_AT_STR = "2000-01-01T01:00:00Z";
	public static final ZonedDateTime CREATED_AT = ZonedDateTime.parse(CREATED_AT_STR);
	public static final UserId CREATED_BY = UserProfileTestFactory.ID;
	public static final Direction DIRECTION = Direction.OUT;
	public static final String RECEIVER = LoremIpsum.getInstance().getEmail();
	public static final String SUBJECT = RandomStringUtils.randomAlphanumeric(70);
	public static final String MAIL_BODY = LoremIpsum.getInstance().getParagraphs(1, 1);
	public static final ReplyOption REPLY_OPTION = ReplyOption.POSSIBLE;
	static final boolean SENT_SUCCESSFUL = true;
	public static final String SENT_AT_STR = "2000-01-01T10:00:00Z";
	public static final ZonedDateTime SENT_AT = ZonedDateTime.parse(SENT_AT_STR);
	public static final String MESSAGE_CODE = LoremIpsum.getInstance().getWords(3).concat(".");

	public static final List<FileId> ATTACHMENTS = List.of(BinaryFileTestFactory.FILE_ID);

	public static PostfachMail create() {
		return createBuilder().build();
	}

	public static PostfachMail createLikeFromClient() {
		return createBuilder()
				.createdAt(null)
				.createdBy(null)
				.direction(null)
				.build();
	}

	public static PostfachMail.PostfachMailBuilder createBuilder() {
		return PostfachMail.builder()
				.id(ID)
				.vorgangId(VORGANG_ID)
				.postfachAddress(PostfachAddressTestFactory.createAsMap())
				.createdAt(CREATED_AT)
				.createdBy(CREATED_BY)
				.sentAt(SENT_AT)
				.sentSuccessful(SENT_SUCCESSFUL)
				.messageCode(MESSAGE_CODE)
				.direction(DIRECTION)
				.subject(SUBJECT)
				.mailBody(MAIL_BODY)
				.replyOption(REPLY_OPTION)
				.attachments(ATTACHMENTS);
	}

	public static String buildSendPostfachMailContent() {
		return buildSendPostfachMailContent(create());
	}

	public static String buildSendPostfachMailContent(PostfachMail postfachMail) {
		return buildSendPostfachMailContent(postfachMail, CommandOrder.SEND_POSTFACH_NACHRICHT);
	}

	public static String buildSendPostfachMailContent(PostfachMail postfachMail, CommandOrder order) {
		return TestUtils.loadTextFile("jsonTemplates/command/createCommandWithPostfachMail.json.tmpl", order.name(),
				postfachMail.getReplyOption().name(),
				TestUtils.addQuote(postfachMail.getSubject()),
				TestUtils.addQuote(postfachMail.getMailBody()),
				buildAttachmentValue(postfachMail));
	}

	private static String buildAttachmentValue(PostfachMail postfachMail) {
		if (postfachMail.getAttachments().isEmpty()) {
			return "[]";
		}
		var fileId = postfachMail.getAttachments().get(0).toString();
		return "[\"api/binaryFiles/" + fileId + "\"]";
	}
}