/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.postfach;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.TestPropertySource;

@SpringBootTest(classes = { PostfachPropertiesTestConfiguration.class })
class PostfachPropertiesTest {
	private static final String ORGANISATIONSEINHEITEN_ID = "oe1";
	private static final String TEST_SIG = "test1";
	private static final String TEST_ORGANISATIONS_SIG = OrganisationsEinheitSettingsTestFactory.TEST_SIGNATUR;

	@DisplayName("Test loading postfach configuration")
	@Nested
	@TestPropertySource(properties = {
			PostfachProperties.PREFIX + ".signatur=" + TEST_SIG,
			PostfachProperties.PREFIX + ".organisations-einheit-settings." + ORGANISATIONSEINHEITEN_ID + ".signatur=" + TEST_ORGANISATIONS_SIG,
	})
	class TestLoadingPostfachProperties {

		@Autowired
		private PostfachProperties postfachProperties;

		@Nested
		class TestInitialization {

			@Test
			void shouldHaveProperties() {
				assertThat(postfachProperties).isNotNull();
			}

			@Test
			void shouldHaveOrganisationsEinheitSettings() {
				assertThat(postfachProperties.getOrganisationsEinheitSettings()).isNotNull();
			}
		}
	}

	@DisplayName("Test mapping organisations einheit settings")
	@Nested
	@TestPropertySource(properties = {
			PostfachProperties.PREFIX + ".signatur=" + TEST_SIG,
			PostfachProperties.PREFIX + ".organisations-einheit-settings.oe1.signatur=" + TEST_ORGANISATIONS_SIG,
	})
	class TestMapOrganisationsEinheitSettings {

		@Autowired
		private PostfachProperties postfachProperties;

		@Test
		void shouldHaveOrganisationsEinheit() {
			var props = postfachProperties.getOrganisationsEinheitSettings();

			assertThat(props).containsKey(ORGANISATIONSEINHEITEN_ID);
		}

		@Test
		void shouldHaveOrganisationsEinheitSetting() {
			assertThat(postfachProperties.getOrganisationsEinheitSettings().get(ORGANISATIONSEINHEITEN_ID)).hasFieldOrPropertyWithValue("signatur",
					TEST_ORGANISATIONS_SIG);
		}
	}
}
