/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.system;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

class SystemStatusServiceTest {

	@InjectMocks
	private SystemStatusService service;

	@Mock
	private SystemStatusRemoteService remoteService;

	@Nested
	class TestIsSearchServerAvailable {

		@BeforeEach
		void mockService() {
			when(remoteService.getSystemStatus()).thenReturn(VorgangManagerSystemStatusTestFactory.create());
		}

		@Test
		void shouldCallRemoteService() {
			service.isSearchServerAvailable();

			verify(remoteService).getSystemStatus();
		}

		@Test
		void shouldRemotAvailablity() {
			var result = service.isSearchServerAvailable();

			assertThat(result).isEqualTo(VorgangManagerSystemStatusTestFactory.SEARCH_AVAILABLE);
		}

		@Test
		void shouldReturnFalseOnError() {
			when(remoteService.getSystemStatus()).thenThrow(RuntimeException.class);
			
			var result = service.isSearchServerAvailable();
			
			assertThat(result).isFalse();
		}
	}
}
