/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.alfa.vorgang.forwarding;

import static org.assertj.core.api.Assertions.*;

import java.util.Arrays;
import java.util.HashSet;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Spy;
import org.springframework.test.util.ReflectionTestUtils;

class ForwardingLandesnetzInfoServiceTest {

	@Spy
	@InjectMocks
	private ForwardingLandesnetzInfoService service;

	@DisplayName("Is email in landesnetz")
	@Nested
	class TestIstInLandesnetz {

		private final String EMAIL_NAME = "testEmailName@";

		private final String IN_LANDESNETZ = "itvsh.de";
		private final String IN_LANDESNETZ_WITH_DOTS = ".itvsh.old.de";

		@BeforeEach
		void initMap() throws Exception {
			ReflectionTestUtils.setField(service, "landesnetzInfo", new HashSet<>(Arrays.asList(IN_LANDESNETZ, IN_LANDESNETZ_WITH_DOTS)));
		}

		@DisplayName("validate with email in Landesnetz")
		@Nested
		class TestWithMatchingEmail {

			@Test
			void shouldReturnTrueWithSingleDot() {
				var result = service.isEmailInLandesnetz(EMAIL_NAME + IN_LANDESNETZ);

				assertThat(result).isTrue();
			}

			@Test
			void shouldReturnTrueWithMultipleDots() {
				var result = service.isEmailInLandesnetz(EMAIL_NAME + IN_LANDESNETZ_WITH_DOTS);

				assertThat(result).isTrue();
			}

			@Test
			void shouldReturnTrueByConsideringJustTheEnd() {
				var result = service.isEmailInLandesnetz(EMAIL_NAME + "me" + IN_LANDESNETZ_WITH_DOTS);

				assertThat(result).isTrue();
			}
		}

		@DisplayName("validate with email NOT in Landesnetz")
		@Nested
		class TestEndsWithMatching {

			@Test
			void shouldReturnFalseOnWrongDomain() {
				var result = service.isEmailInLandesnetz(EMAIL_NAME + "me.gmx.de");

				assertThat(result).isFalse();
			}

			@Test
			void shouldReturnFalseOnConsideringJustTheEnd() {
				var result = service.isEmailInLandesnetz(EMAIL_NAME + "me" + IN_LANDESNETZ_WITH_DOTS + ".nicht.gueltig.de");

				assertThat(result).isFalse();
			}
		}
	}
}